==> firefox-61.0b6.source.tar.xz: firefox-61.0/browser/extensions/activity-stream/prerendered/locales/en-CA/activity-stream-strings.js <==
// Note - this is a generated en-CA file.
window.gActivityStreamStrings = {
  "newtab_page_title": "New Tab",
  "header_top_sites": "Top Sites",
  "header_highlights": "Highlights",
  "header_recommended_by": "Recommended by {provider}",
  "context_menu_button_sr": "Open context menu for {title}",
  "section_context_menu_button_sr": "Open the section context menu",
  "type_label_visited": "Visited",
  "type_label_bookmarked": "Bookmarked",
  "type_label_recommended": "Trending",
  "type_label_pocket": "Saved to Pocket",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "Bookmark",
  "menu_action_remove_bookmark": "Remove Bookmark",
  "menu_action_open_new_window": "Open in a New Window",
  "menu_action_open_private_window": "Open in a New Private Window",
  "menu_action_dismiss": "Dismiss",
  "menu_action_delete": "Delete from History",
  "menu_action_pin": "Pin",
  "menu_action_unpin": "Unpin",
  "confirm_history_delete_p1": "Are you sure you want to delete every instance of this page from your history?",
  "confirm_history_delete_notice_p2": "This action cannot be undone.",
  "menu_action_save_to_pocket": "Save to Pocket",
  "menu_action_delete_pocket": "Delete from Pocket",
  "menu_action_archive_pocket": "Archive in Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "Search",
  "search_header": "{search_engine_name} Search",
  "search_web_placeholder": "Search the Web",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "Learn how it works.",
  "section_disclaimer_topstories_buttontext": "Okay, got it",
  "prefs_home_header": "Firefox Home Content",
  "prefs_home_description": "Choose what content you want on your Firefox Home screen.",
  "prefs_section_rows_option": "{num} row;{num} rows",
  "prefs_search_header": "Web Search",
  "prefs_topsites_description": "The sites you visit most",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "Learn more",
  "prefs_highlights_description": "A selection of sites that you’ve saved or visited",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Updates from Mozilla and Firefox",
  "settings_pane_button_label": "Customise your New Tab page",
  "settings_pane_topsites_header": "Top Sites",
  "settings_pane_highlights_header": "Highlights",
  "settings_pane_highlights_options_bookmarks": "Bookmarks",
  "settings_pane_snippets_header": "Snippets",
  "edit_topsites_button_text": "Edit",
  "edit_topsites_edit_button": "Edit this site",
  "topsites_form_add_header": "Top Sites",
  "topsites_form_edit_header": "Edit Top Site",
  "topsites_form_title_label": "Title",
  "topsites_form_title_placeholder": "Enter a title",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Custom Image URL",
  "topsites_form_url_placeholder": "Type or paste a URL",
  "topsites_form_use_image_link": "Use a custom image…",
  "topsites_form_preview_button": "Preview",
  "topsites_form_add_button": "Add",
  "topsites_form_save_button": "Save",
  "topsites_form_cancel_button": "Cancel",
  "topsites_form_url_validation": "Valid URL required",
  "topsites_form_image_validation": "Image failed to load. Try a different URL.",
  "pocket_read_more": "Popular Topics:",
  "pocket_read_even_more": "View More Stories",
  "highlights_empty_state": "Start browsing, and we’ll show some of the great articles, videos, and other pages you’ve recently visited or bookmarked here.",
  "topstories_empty_state": "You’ve caught up. Check back later for more top stories from {provider}. Can’t wait? Select a popular topic to find more great stories from around the web.",
  "manual_migration_explanation2": "Try Firefox with the bookmarks, history and passwords from another browser.",
  "manual_migration_cancel_button": "No Thanks",
  "manual_migration_import_button": "Import Now",
  "error_fallback_default_info": "Oops, something went wrong loading this content.",
  "error_fallback_default_refresh_suggestion": "Refresh page to try again.",
  "section_menu_action_remove_section": "Remove Section",
  "section_menu_action_collapse_section": "Collapse Section",
  "section_menu_action_expand_section": "Expand Section",
  "section_menu_action_manage_section": "Manage Section",
  "section_menu_action_add_topsite": "Add Top Site",
  "section_menu_action_move_up": "Move Up",
  "section_menu_action_move_down": "Move Down",
  "section_menu_action_privacy_notice": "Privacy Notice",
  "prefs_restore_defaults_button": "Restore Defaults",
  "prefs_topstories_description": "High-quality content you might otherwise miss",
  "prefs_topstories_show_sponsored_label": "{provider} Sponsored Stories",
  "settings_pane_header": "New Tab Preferences",
  "settings_pane_body2": "Choose what you see on this page.",
  "settings_pane_search_header": "Search",
  "settings_pane_search_body": "Search the Web from your new tab.",
  "settings_pane_topsites_body": "Access the web sites you visit most.",
  "settings_pane_topsites_options_showmore": "Show two rows",
  "settings_pane_highlights_body2": "Find your way back to interesting things you’ve recently visited or bookmarked.",
  "settings_pane_highlights_options_visited": "Visited Sites",
  "settings_pane_snippets_body": "Read short and sweet updates from Mozilla about Firefox, internet culture, and the occasional random meme.",
  "settings_pane_done_button": "Done",
  "settings_pane_topstories_options_sponsored": "Show Sponsored Stories",
  "pocket_description": "Discover high-quality content you might otherwise miss, with help from Pocket, now part of Mozilla."
};

==> firefox-62.0b18.source.tar.xz: firefox-62.0/browser/extensions/activity-stream/prerendered/locales/en-CA/activity-stream-strings.js <==
// Note - this is a generated en-CA file.
window.gActivityStreamStrings = {
  "newtab_page_title": "New Tab",
  "header_top_sites": "Top Sites",
  "header_highlights": "Highlights",
  "header_recommended_by": "Recommended by {provider}",
  "context_menu_button_sr": "Open context menu for {title}",
  "section_context_menu_button_sr": "Open the section context menu",
  "type_label_visited": "Visited",
  "type_label_bookmarked": "Bookmarked",
  "type_label_recommended": "Trending",
  "type_label_pocket": "Saved to Pocket",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "Bookmark",
  "menu_action_remove_bookmark": "Remove Bookmark",
  "menu_action_open_new_window": "Open in a New Window",
  "menu_action_open_private_window": "Open in a New Private Window",
  "menu_action_dismiss": "Dismiss",
  "menu_action_delete": "Delete from History",
  "menu_action_pin": "Pin",
  "menu_action_unpin": "Unpin",
  "confirm_history_delete_p1": "Are you sure you want to delete every instance of this page from your history?",
  "confirm_history_delete_notice_p2": "This action cannot be undone.",
  "menu_action_save_to_pocket": "Save to Pocket",
  "menu_action_delete_pocket": "Delete from Pocket",
  "menu_action_archive_pocket": "Archive in Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "Search",
  "search_header": "{search_engine_name} Search",
  "search_web_placeholder": "Search the Web",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "Learn how it works.",
  "section_disclaimer_topstories_buttontext": "Okay, got it",
  "prefs_home_header": "Firefox Home Content",
  "prefs_home_description": "Choose what content you want on your Firefox Home screen.",
  "prefs_section_rows_option": "{num} row;{num} rows",
  "prefs_search_header": "Web Search",
  "prefs_topsites_description": "The sites you visit most",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "Learn more",
  "prefs_highlights_description": "A selection of sites that you’ve saved or visited",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Updates from Mozilla and Firefox",
  "settings_pane_button_label": "Customize your New Tab page",
  "settings_pane_topsites_header": "Top Sites",
  "settings_pane_highlights_header": "Highlights",
  "settings_pane_highlights_options_bookmarks": "Bookmarks",
  "settings_pane_snippets_header": "Snippets",
  "edit_topsites_button_text": "Edit",
  "edit_topsites_edit_button": "Edit this site",
  "topsites_form_add_header": "Top Sites",
  "topsites_form_edit_header": "Edit Top Site",
  "topsites_form_title_label": "Title",
  "topsites_form_title_placeholder": "Enter a title",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Custom Image URL",
  "topsites_form_url_placeholder": "Type or paste a URL",
  "topsites_form_use_image_link": "Use a custom image…",
  "topsites_form_preview_button": "Preview",
  "topsites_form_add_button": "Add",
  "topsites_form_save_button": "Save",
  "topsites_form_cancel_button": "Cancel",
  "topsites_form_url_validation": "Valid URL required",
  "topsites_form_image_validation": "Image failed to load. Try a different URL.",
  "pocket_read_more": "Popular Topics:",
  "pocket_read_even_more": "View More Stories",
  "highlights_empty_state": "Start browsing, and we’ll show some of the great articles, videos, and other pages you’ve recently visited or bookmarked here.",
  "topstories_empty_state": "You’ve caught up. Check back later for more top stories from {provider}. Can’t wait? Select a popular topic to find more great stories from around the web.",
  "manual_migration_explanation2": "Try Firefox with the bookmarks, history and passwords from another browser.",
  "manual_migration_cancel_button": "No Thanks",
  "manual_migration_import_button": "Import Now",
  "error_fallback_default_info": "Oops, something went wrong loading this content.",
  "error_fallback_default_refresh_suggestion": "Refresh page to try again.",
  "section_menu_action_remove_section": "Remove Section",
  "section_menu_action_collapse_section": "Collapse Section",
  "section_menu_action_expand_section": "Expand Section",
  "section_menu_action_manage_section": "Manage Section",
  "section_menu_action_manage_webext": "Manage Extension",
  "section_menu_action_add_topsite": "Add Top Site",
  "section_menu_action_add_search_engine": "Add Search Engine",
  "section_menu_action_move_up": "Move Up",
  "section_menu_action_move_down": "Move Down",
  "section_menu_action_privacy_notice": "Privacy Notice",
  "firstrun_title": "Take Firefox with You",
  "firstrun_content": "Get your bookmarks, history, passwords and other settings on all your devices.",
  "firstrun_learn_more_link": "Learn more about Firefox Accounts",
  "firstrun_form_header": "Enter your email",
  "firstrun_form_sub_header": "to continue to Firefox Sync.",
  "firstrun_email_input_placeholder": "Email",
  "firstrun_invalid_input": "Valid email required",
  "firstrun_extra_legal_links": "By proceeding, you agree to the {terms} and {privacy}.",
  "firstrun_terms_of_service": "Terms of Service",
  "firstrun_privacy_notice": "Privacy Notice",
  "firstrun_continue_to_login": "Continue",
  "firstrun_skip_login": "Skip this step",
  "prefs_restore_defaults_button": "Restore Defaults",
  "prefs_topstories_description": "High-quality content you might otherwise miss",
  "prefs_topstories_show_sponsored_label": "{provider} Sponsored Stories",
  "settings_pane_header": "New Tab Preferences",
  "settings_pane_body2": "Choose what you see on this page.",
  "settings_pane_search_header": "Search",
  "settings_pane_search_body": "Search the Web from your new tab.",
  "settings_pane_topsites_body": "Access the web sites you visit most.",
  "settings_pane_topsites_options_showmore": "Show two rows",
  "settings_pane_highlights_body2": "Find your way back to interesting things you’ve recently visited or bookmarked.",
  "settings_pane_highlights_options_visited": "Visited Sites",
  "settings_pane_snippets_body": "Read short and sweet updates from Mozilla about Firefox, internet culture, and the occasional random meme.",
  "settings_pane_done_button": "Done",
  "settings_pane_topstories_options_sponsored": "Show Sponsored Stories",
  "pocket_description": "Discover high-quality content you might otherwise miss, with help from Pocket, now part of Mozilla."
};
